@@ -98,6 +98,12 @@ seurat_to_generes <- function(pbmc, test = "wilcox"){
     message("DE")
     message(i)
   }
+  if(is.null(generes[[1]]$avg_logFC)) {
+    message("Seurat V4 or later was used to identify cell-type markers, adding 'avg_logFC' column. It has the same data as avg_log2FC but is compatible with downstream functions in scMappR.")
+    for(z in 1:length(generes))
+      generes[[z]]$avg_logFC <- generes[[z]]$avg_log2FC
+  }
+  
   return(generes)
 }
 
